from distutils.core import setup


setup(
    name = 'umnester',
    version = '1.2.0',
    py_modules = ['umnasted'],
    author = 'Umair',
    author_email = 'um_trade@yahoo.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
    )
